@@ -43,6 +43,7 @@ from ..tomlfile import PathTomlEncoder
 from ..tomlfile import TomlEvents
 from ..tomlfile import TomlFile
 from ..tomlfile import TomlValue
+from ..utils import format_tb
 from ..utils import has_package
 from ..utils import hide_windows_file
 from ..utils import http_code_map
@@ -158,6 +159,8 @@ class GetterApp(Singleton, QApplication):
         self._create_windows()
         self.updateTranslations.emit()
 
+        self.version_checker.check_version(CG_PACKAGE_NAME)
+
     @property
     def first_launch(self) -> bool:
         """Return whether this is the first launch of the application.
@@ -181,7 +184,8 @@ class GetterApp(Singleton, QApplication):
         )
 
         self.client.authenticator.authenticationFailed.connect(
-            lambda email, e: self.show_dialog('errors.authentication_failed', description_args=(email, e))
+            lambda email, e: self.show_dialog('errors.authentication_failed', description_args=(email, e),
+                                              details_text=format_tb(e.__traceback__))
         )
 
     def _create_paths(self) -> None:
@@ -443,9 +447,11 @@ class GetterApp(Singleton, QApplication):
             description_args=(version, __version__)
         ).role:
             case QMessageBox.ButtonRole.YesRole:
-                QProcess.execute('pip', arguments=('install', '--upgrade', f'{CG_PACKAGE_NAME.replace("_", "-")}'))
-                QProcess.startDetached(sys.executable, arguments=('-m', CG_PACKAGE_NAME))
-                self.exit(0)
+                QProcess.startDetached(sys.executable, arguments=(
+                    str((CG_RESOURCE_PATH / 'scripts/upgrade_version.py').absolute().resolve(True)),
+                    f'{CG_PACKAGE_NAME.replace("_", "-")}', CG_PACKAGE_NAME
+                ))
+                sys.exit(0)
             case QMessageBox.ButtonRole.NoRole:
                 self.version_checker.newerVersion.disconnect(self._upgrade_version_dialog)
                 self.settings['ignore_updates'] = True
