@@ -212,10 +212,13 @@ class Client(QObject):
         return self._get('backend-api/models').json.get('models')
 
     def get_image(self, url: str) -> bytes:
-        """Get the list of models to use with ChatGPT.
+        """Get an image using ChatGPT.
 
-        :return: List of model data. The "slug" key is the model name.
-        :raises ValueError: If request failed.
+        This should be used for things like profile icons, which are behind an auth0 server.
+
+        :param url: Url of the image resource.
+        :return: Image's byte data.
+        :raises ValueError: If the response returned an error code.
         """
         response: Response = self._get('_next/image', params={
             'url': url,
@@ -224,7 +227,7 @@ class Client(QObject):
         })
 
         if not response.ok:
-            raise ValueError(f'Couldn\'t get image for {url} at {response.url}.')
+            raise ValueError(f'Couldn\'t get image for {url} at {response.url}. Error {response.code}')
 
         return response.data
 
